#
# Copyright (C) 2015 Samuel Thibault <samuel.thibault@ens-lyon.org>
# 
# This program is free software ; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation ; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY ; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
# 

. /usr/lib/cups/filter/index.sh

if [ $FIRMWARE -ge 103000 ]
then
  # Firmware 10.30 and above support temporary parameters
  INIT="D"

  # Disable margins
  INIT+=TM0,BI0

  # Common options
  INIT+="$(setCommonOptions)"

  # Paper size
  INIT+=,CH$TEXTWIDTH,LP$TEXTHEIGHT

  case $LINESPACING in
    500)  INIT+=,LS50 ;;
    1000) INIT+=,LS100 ;;
    *)
      echo "ERROR: unsupported $LINESPACING line spacing" >&2
      exit 1
      ;;
  esac

  if [ $LIBLOUIS1 != None -o \
       $LIBLOUIS2 != None -o \
       $LIBLOUIS3 != None -o \
       $LIBLOUIS4 != None ]
  then
    # software-translated, enforce a 6-dot table if needed
    case $TEXTDOTS in
      # Firmware 11.02.1 and above allow to make sure to be using a 6-dot table
      6) INIT+=,BT0 ;;
      # Firmware 11.02.1 and above allow to make sure to be using a 8-dot table
      8) INIT+=,BT6 ;;
      *)   echo "ERROR: unsupported $TEXTDOTS dots" >&2 ; exit 1 ;;
    esac
  else
    # Hoping the user configured a table with appropriate number of dots
    INIT+=,BT$TABLE
  fi

  # roger
  INIT+=";"
else
  # No support for temporary parameters.  Hoping that the user configured CUPS
  # the same way as the embosser.
  INIT=
fi
